/*
** Class:  LotROLinux.DetermineOS
** Author: Alan Jackson
** Date:   15th May 2008
**
** Class to determine which Operating System is in use
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using System;
using System.Diagnostics;

namespace LotROLinux
{
	public class DetermineOS
	{
		private const string keyAppDirLinux = ".LotROLinux/";
		private const string keyAppDirMac = "Library/Application Support/LotROLinux/";
		private const string keySettingsCXGLinux = ".cxgames";
		private const string keySettingsCXGMac = "Library/Application Support/CrossOver Games/Bottles";
		private const string keySettingsCXOLinux = ".cxoffice";
		private const string keySettingsCXOMac = "Library/Application Support/CrossOver/Bottles";
		private const string keyDirectoryCXGLinux = "/cxgames/bin/";
		private const string keyDirectoryCXGMac = "/CrossOver Games.app/Contents/SharedSupport/CrossOverGames/bin/";
		private const string keyDirectoryCXOLinux = "/cxoffice/bin/";
		private const string keyDirectoryCXOMac = "/CrossOver.app/Contents/SharedSupport/CrossOver/bin/";
		private const string keyGlobalDirLinux = "/opt";
		private const string keyGlobalDirMac = "/Application";

		private string appDir;
		private string globalDir;
		private string settingsCXG;
		private string settingsCXO;
		private string directoryCXG;
		private string directoryCXO;
		private string macPathCX;
		private bool usingLinux;

		public DetermineOS()
		{
			usingLinux = false;
			macPathCX = "";

			Process temp = new Process();

			temp.StartInfo.FileName = "uname";
			temp.StartInfo.Arguments = "-s";
			temp.StartInfo.UseShellExecute = false;
			temp.StartInfo.RedirectStandardOutput = true;

			try
			{
				temp.Start();
				temp.WaitForExit();

				foreach (string s in temp.StandardOutput.ReadToEnd().Split('\n','\r')) 
				{
					if (s.ToUpper().Contains("LINUX"))
					{
						usingLinux = true;
					}
				}
			}
			catch
			{
				usingLinux = true;
			}

			if (usingLinux)
			{
				appDir = keyAppDirLinux;
				globalDir = keyGlobalDirLinux;
				settingsCXG = keySettingsCXGLinux;
				settingsCXO = keySettingsCXOLinux;
				directoryCXG = keyDirectoryCXGLinux;
				directoryCXO = keyDirectoryCXOLinux;
			} else {
				appDir = keyAppDirMac;
				globalDir = keyGlobalDirMac;
				settingsCXG = keySettingsCXGMac;
				settingsCXO = keySettingsCXOMac;
				directoryCXG = keyDirectoryCXGMac;
				directoryCXO = keyDirectoryCXOMac;

				if (System.Environment.GetEnvironmentVariable("CX_ROOT") != null)
				{
					macPathCX = String.Format("{0}/bin/", System.Environment.GetEnvironmentVariable("CX_ROOT"));
				}
			}
		}

		public string AppDir
        {
        	get { return appDir; }
        }

		public string GlobalDir
        {
        	get { return globalDir; }
        }

		public string DirectoryCXG
        {
        	get { return directoryCXG; }
        }

		public string DirectoryCXO
        {
        	get { return directoryCXO; }
        }

		public string MacPathCX
        {
        	get { return macPathCX; }
        }

		public string SettingsCXG
        {
        	get { return settingsCXG; }
        }

		public string SettingsCXO
        {
        	get { return settingsCXO; }
        }

		public bool UsingLinux
        {
        	get { return usingLinux; }
        }
	}
}
